@@ -25,35 +25,18 @@
 #include <QList>
 #include <AppStreamQt/image.h>
 #include <AppStreamQt/component.h>
-#include <AppStreamQt/release.h>
 
 namespace AppStreamUtils
 {
-static QUrl imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind)
-{
-    QUrl ret;
-    Q_FOREACH (const AppStream::Image &i, images) {
-        if (i.kind() == kind) {
-            ret = i.url();
-            break;
-        }
-    }
-    return ret;
-}
+Q_DECL_EXPORT QUrl imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind);
 
-static QString changelogToHtml(const AppStream::Component &appdata)
-{
-    if(appdata.releases().isEmpty())
-        return {};
+Q_DECL_EXPORT QString changelogToHtml(const AppStream::Component &appdata);
 
-    const auto release = appdata.releases().constFirst();
-    if (release.description().isEmpty())
-        return {};
+Q_DECL_EXPORT QPair<QList<QUrl>, QList<QUrl>> fetchScreenshots(const AppStream::Component &appdata);
 
-    QString changelog = QStringLiteral("<h3>") + release.version() + QStringLiteral("</h3>")
-                      + QStringLiteral("<p>") + release.description() + QStringLiteral("</p>");
-    return changelog;
-}
+Q_DECL_EXPORT QJsonArray licenses(const AppStream::Component &appdata);
+
+Q_DECL_EXPORT QString appstreamId(const QUrl &appstreamUrl);
 
 }
 
